@@ -4,6 +4,8 @@ from django.http import JsonResponse
 
 
 class SemanticAutocompleteJsonView(AutocompleteJsonView):
+    # TODO: Delete overridden get method once serialize_result is released
+    # in a future Django version
     def get(self, request, *args, **kwargs):
         """
         Return a JsonResponse with search results of the form:
@@ -28,14 +30,21 @@ class SemanticAutocompleteJsonView(AutocompleteJsonView):
             {
                 # BEGIN CUSTOMIZATION #
                 "results": [
-                    {
-                        "id": str(getattr(obj, to_field_name)),
-                        "name": getattr(obj, "semantic_autocomplete", str(obj)),
-                        "text": str(obj),
-                    }
+                    self.serialize_result(obj, to_field_name)
                     for obj in context["object_list"]
                 ],
                 # END CUSTOMIZATION #
                 "pagination": {"more": context["page_obj"].has_next()},
             }
         )
+
+    def serialize_result(self, obj, to_field_name):
+        """
+        Convert the provided model object to a dictionary that is added to the
+        results list.
+        """
+        return {
+            "id": str(getattr(obj, to_field_name)),
+            "name": getattr(obj, "semantic_autocomplete", str(obj)),
+            "text": str(obj),
+        }
